@@ -30,6 +30,42 @@ import sys
 import time
 import Wammu.Events
 
+class LoggerDebug(threading.Thread):
+    '''
+    Thread which reads defined files and prints it to stderr.
+    '''
+    def __init__(self, filename):
+        '''
+        Initializes reader on filename, text will be printed to stderr.
+        '''
+        threading.Thread.__init__(self)
+        self.file_descriptor = open(filename, 'r')
+        self.filename = filename
+        self.canceled = False
+
+    def run(self):
+        """
+        This is basically tail -f reimplementation
+        """
+        while not self.canceled:
+            where = self.file_descriptor.tell()
+            txt = self.file_descriptor.readlines()
+            if len(txt) == 0:
+                fd_results = os.fstat(self.file_descriptor.fileno())
+                try:
+                    st_results = os.stat(self.filename)
+                except OSError:
+                    st_results = fd_results
+
+                if st_results[1] == fd_results[1] or sys.platform == 'win32':
+                    time.sleep(1)
+                    self.file_descriptor.seek(where)
+                else:
+                    self.file_descriptor = open(self.filename, 'r')
+            else:
+                sys.stderr.write(''.join(txt))
+        self.file_descriptor.close()
+
 class Logger(threading.Thread):
     '''
     Thread which reads defined files and posts events on change.
@@ -80,24 +116,24 @@ class LogFrame(wx.Frame):
         self.cfg = cfg
         if cfg.HasEntry('/Debug/X') and cfg.HasEntry('/Debug/Y'):
             pos = wx.Point(
-                    cfg.ReadInt('/Debug/X'), 
+                    cfg.ReadInt('/Debug/X'),
                     cfg.ReadInt('/Debug/Y'))
         else:
             pos = wx.DefaultPosition
         size = wx.Size(
-                cfg.ReadInt('/Debug/Width'), 
+                cfg.ReadInt('/Debug/Width'),
                 cfg.ReadInt('/Debug/Height'))
         wx.Frame.__init__(
-                self, 
-                parent, 
-                -1, 
-                _('Wammu debug log'), 
-                pos, 
-                size, 
+                self,
+                parent,
+                -1,
+                _('Wammu debug log'),
+                pos,
+                size,
                 wx.DEFAULT_FRAME_STYLE | wx.RESIZE_BORDER)
         self.txt = wx.TextCtrl(
                 self,
-                -1, 
+                -1,
                 _('Here will appear debug messages from Gammu...\n'),
                 style = wx.TE_MULTILINE | wx.TE_READONLY)
         self.txt.SetFont(wx.Font(9, wx.MODERN, wx.NORMAL, wx.NORMAL))
