@@ -77,6 +77,7 @@ import Wammu.ErrorMessage
 import Wammu.TalkbackDialog
 import Wammu.WammuSettings
 import Wammu.SMSExport
+import Wammu.SMSXML
 from Wammu.Locales import StrConv, ConsoleStrConv
 
 TALKBACK_COUNT = 30
@@ -286,7 +287,7 @@ class WammuFrame(wx.Frame):
         menu1.Append(150, _('&Phone wizard'), _('Search for phone or configure it using guided wizard.'))
         menu1.Append(151, _('Se&ttings'), _('Change Wammu settings.'))
         menu1.AppendSeparator()
-        menu1.Append(199, _('E&xit'), _('Terminate Wammu.'))
+        menu1.Append(199, '%s\tCtrl+Q' % _('E&xit'), _('Terminate Wammu.'))
         # Add menu to the menu bar
         self.menuBar.Append(menu1, _('&Wammu'))
 
@@ -301,7 +302,7 @@ class WammuFrame(wx.Frame):
         self.menuBar.Append(menu2, _('&Phone'))
 
         menu3 = wx.Menu()
-        menu3.Append(301, _('&Info'), _('Retrieve phone information.'))
+        menu3.Append(301, '%s\tCtrl+I' % _('&Info'), _('Retrieve phone information.'))
         menu3.AppendSeparator()
         menu3.Append(310, _('Contacts (&SIM)'), _('Retrieve contacts from SIM.'))
         menu3.Append(311, _('Contacts (&phone)'), _('Retrieve contacts from phone memory.'))
@@ -318,10 +319,10 @@ class WammuFrame(wx.Frame):
         self.menuBar.Append(menu3, _('&Retrieve'))
 
         menu4 = wx.Menu()
-        menu4.Append(401, _('&Contact'), _('Create new contact.'))
-        menu4.Append(402, _('Calendar &event'), _('Create new calendar event.'))
-        menu4.Append(403, _('&Todo'), _('Create new todo.'))
-        menu4.Append(404, _('&Message'), _('Create new message.'))
+        menu4.Append(401, '%s\tCtrl+N' % _('&Contact'), _('Create new contact.'))
+        menu4.Append(402, '%s\tCtrl+E' % _('Calendar &event'), _('Create new calendar event.'))
+        menu4.Append(403, '%s\tCtrl+T' % _('&Todo'), _('Create new todo.'))
+        menu4.Append(404, '%s\tCtrl+M' % _('&Message'), _('Create new message.'))
         # Add menu to the menu bar
         self.menuBar.Append(menu4, _('&Create'))
 
@@ -332,6 +333,7 @@ class WammuFrame(wx.Frame):
         menu5.Append(504, _('I&mport messages'), _('Import messages from backup to phone.'))
         menu5.AppendSeparator()
         menu5.Append(510, _('Export messages to &emails'), _('Export messages to emails in storage you choose.'))
+        menu5.Append(511, _('Export messages to &XML'), _('Export messages to XML file you choose.'))
         # Add menu to the menu bar
         self.menuBar.Append(menu5, _('&Backups'))
 
@@ -386,6 +388,8 @@ class WammuFrame(wx.Frame):
         wx.EVT_MENU(self, 503, self.Import)
         wx.EVT_MENU(self, 504, self.ImportSMS)
         wx.EVT_MENU(self, 510, self.SMSToMails)
+        wx.EVT_MENU(self, 511, self.SMSToXML)
+
 
         wx.EVT_MENU(self, 1001, self.Website)
         wx.EVT_MENU(self, 1002, self.Support)
@@ -423,6 +427,10 @@ class WammuFrame(wx.Frame):
             gammu.SetDebugFile(self.logfilefd)
             gammu.SetDebugLevel('textalldate')
 
+            if Wammu.debug:
+                self.loggerdebug = Wammu.Logger.LoggerDebug(self.logfilename)
+                self.loggerdebug.start()
+
         # initialize variables
         self.showdebug = ''
         self.IMEI = ''
@@ -784,6 +792,7 @@ class WammuFrame(wx.Frame):
         mb.Enable(504, enable);
 
         mb.Enable(510, enable);
+        mb.Enable(511, enable);
 
     def ActivateView(self, k1, k2):
         self.tree.SelectItem(self.treei[k1][k2])
@@ -872,6 +881,10 @@ class WammuFrame(wx.Frame):
             self.logger.canceled = True
             self.logger.join()
 
+        if hasattr(self, 'loggerdebug'):
+            self.loggerdebug.canceled = True
+            self.loggerdebug.join()
+
         if self.tbicon is not None:
             self.tbicon.Destroy()
 
@@ -1103,7 +1116,15 @@ class WammuFrame(wx.Frame):
 
                 # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                 try:
-                    v = self.sm.GetMemory(v['MemoryType'], v['Location'])
+                    attempts = 0
+                    while attempts < 10:
+                        try:
+                            v = self.sm.GetMemory(v['MemoryType'], v['Location'])
+                            break
+                        except gammu.ERR_EMPTY:
+                            # some phones need time till entry appears
+                            attempts = attempts + 1
+                            time.sleep(1)
                 except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
                     wx.MessageDialog(self, _('It was not possible to read saved entry! It might be different than one saved in phone untill you reread all entries.'), _('Could not read saved entry!'), wx.OK | wx.ICON_WARNING).ShowModal()
                 Wammu.Utils.ParseMemoryEntry(v, self.cfg)
@@ -1327,6 +1348,15 @@ class WammuFrame(wx.Frame):
             self.values['contact']['SM']
         Wammu.SMSExport.SMSExport(self, messages, contacts)
 
+    def SMSToXML(self, evt):
+        messages = self.values['message']['Read'] + \
+            self.values['message']['UnRead'] + \
+            self.values['message']['Sent'] + \
+            self.values['message']['UnSent']
+        contacts =  self.values['contact']['ME'] + \
+            self.values['contact']['SM']
+        Wammu.SMSXML.SMSExportXML(self, messages, contacts)
+
     def SelectBackupFile(self, type, save = True, data = False):
         wildcard = ''
         if type == 'message':
@@ -1486,13 +1516,21 @@ class WammuFrame(wx.Frame):
 
                     self.ActivateView('message', '  ')
 
+            del busy
+            wx.Yield()
+
+            wx.MessageDialog(self,
+                _('Backup has been imported from file "%s"') % filename,
+                _('Backup imported'),
+                wx.OK | wx.ICON_INFORMATION).ShowModal()
+
         except gammu.GSMError, val:
             self.ShowError(val[0])
 
-        wx.MessageDialog(self,
-            _('Backup has been imported from file "%s"') % filename,
-            _('Backup imported'),
-            wx.OK | wx.ICON_INFORMATION).ShowModal()
+            wx.MessageDialog(self,
+                _('Restoring from file "%s" has failed, some parts of backup might have been stored to phone and some were not.') % filename,
+                _('Backup import failed'),
+                wx.OK | wx.ICON_INFORMATION).ShowModal()
 
     def Import(self, evt):
         (filename, backup) = self.ReadBackup('all')
@@ -1586,13 +1624,22 @@ class WammuFrame(wx.Frame):
                         # append new value to list
                         self.values['calendar']['  '].append(v)
                     self.ActivateView('calendar', '  ')
+
+            del busy
+            wx.Yield()
+
+            wx.MessageDialog(self,
+                _('Backup has been imported from file "%s"') % filename,
+                _('Backup imported'),
+                wx.OK | wx.ICON_INFORMATION).ShowModal()
+
         except gammu.GSMError, val:
             self.ShowError(val[0])
 
-        wx.MessageDialog(self,
-            _('Backup has been imported from file "%s"') % filename,
-            _('Backup imported'),
-            wx.OK | wx.ICON_INFORMATION).ShowModal()
+            wx.MessageDialog(self,
+                _('Restoring from file "%s" has failed, some parts of backup might have been stored to phone and some were not.') % filename,
+                _('Backup import failed'),
+                wx.OK | wx.ICON_INFORMATION).ShowModal()
 
     def WriteData(self, evt):
         self.DoBackup(True, 'all')
