@@ -116,26 +116,31 @@ class Reader(Wammu.Thread.Thread):
                         value = self.GetNextStart()
                         start = False
                     else:
-                        try:
-                            loc = value['Location']
-                        except TypeError:
-                            loc = value[0]['Location']
                         value = self.GetNext(loc)
+                    try:
+                        loc = value['Location']
+                    except TypeError:
+                        loc = value[0]['Location']
+                    self.Parse(value)
+                    if type(value) == list:
+                        for i in range(len(value)):
+                            value[i]['Synced'] = True
+                    else:
+                        value['Synced'] = True
+                    data.append(value)
+                except gammu.ERR_UNKNOWN:
+                    self.ShowMessage(
+                            _('Ignoring unknown'),
+                            _('While reading, entry on location %d reported unknown error, ignoring it!') % loc)
+                    loc = loc + 1
                 except gammu.ERR_CORRUPTED:
                     self.ShowMessage(
                             _('Ignoring corrupted'),
                             _('While reading, entry on location %d seems to be corrupted, ignoring it!') % loc)
-                    continue
+                    loc = loc + 1
                 except gammu.ERR_EMPTY:
                     break
 
-                self.Parse(value)
-                if type(value) == list:
-                    for i in range(len(value)):
-                        value[i]['Synced'] = True
-                else:
-                    value['Synced'] = True
-                data.append(value)
                 remain = remain - 1
         except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
             location = 1
@@ -173,12 +178,17 @@ class Reader(Wammu.Thread.Thread):
                     self.ShowMessage(
                             _('Ignoring corrupted'),
                             _('While reading, entry on location %d seems to be corrupted, ignoring it!') % location)
-                    continue
+                    remain = remain - 1
+                except gammu.ERR_UNKNOWN:
+                    self.ShowMessage(
+                            _('Ignoring unknown'),
+                            _('While reading, entry on location %d reported unknown error, ignoring it!') % location)
+                    remain = remain - 1
                 except gammu.GSMError, val:
                     self.ShowError(val[0], True)
                     return
                 location = location + 1
-        except gammu.ERR_INVALIDLOCATION:
+        except gammu.ERR_INVALIDLOCATION, val:
             # if we reached end with guess, it is okay
             if not guess:
                 self.ShowError(val[0], True)
