@@ -149,7 +149,7 @@ def NormalizeNumber(number):
         resnumber = '+' + resnumber[2:]
     # Detect numbers with international prefix and without +
     # This can be national number in some countries (eg. US)
-    if NumberPrefix[0] == '+' and resnumber[:len(NumberPrefix) - 1] == NumberPrefix[1:]:
+    if NumberPrefix[0] == '+' and len(NumberPrefix) > 0 and resnumber[:len(NumberPrefix) - 1] == NumberPrefix[1:]:
         resnumber = '+' + resnumber
     # Add international prefix
     if resnumber[0] != '+':
@@ -217,7 +217,13 @@ def ParseMemoryEntry(entry, config = None):
         if i['Type'] == 'Text_FormalName':
             formalname = i['Value']
         if i['Type'] == 'Date':
-            date = i['Value']
+            # Store date olny if it is more recent
+            # This can happen in multiple call records
+            if date is None:
+                date = i['Value']
+            else:
+                if i['Value'] > date:
+                    date = i['Value']
         if i['Type'] == 'Text_Company':
             company = i['Value']
         if i['Type'] == 'Number_General':
